@@ -2,7 +2,7 @@
 # Author: hankcs
 # Date: 2020-11-29 17:48
 import json
-from typing import Union, List, Optional, Dict, Any
+from typing import Union, List, Optional, Dict, Any, Tuple
 from urllib.error import HTTPError
 from urllib.parse import urlencode
 from urllib.request import Request, urlopen
@@ -162,3 +162,53 @@ class HanLPClient(object):
 
     def _send_get_json(self, url, form: Dict[str, Any]):
         return json.loads(self._send_get(url, form))
+
+    def text_style_transfer(self, text: Union[str, List[str]], target_style: str, language: str = None) \
+            -> Union[str, List[str]]:
+        """ Text style transfer aims to change the style of the input text to the target style while preserving its
+        content.
+
+        Args:
+            text: Source text.
+            target_style: Target style.
+            language: The language of input text. ``None`` to use the default language.
+
+        Examples::
+
+            HanLP.text_style_transfer(['国家对中石油抱有很大的期望.', '要用创新去推动高质量的发展。'],
+                                      target_style='gov_doc')
+            # Output: ['国家对中石油寄予厚望。', '要以创新驱动高质量发展。']
+
+        Returns:
+            Text or a list of text of the target style.
+
+        """
+        response = self._send_post_json(self._url + '/text_style_transfer',
+                                        {'text': text, 'target_style': target_style,
+                                         'language': language or self._language})
+        return response
+
+    def semantic_textual_similarity(self, text: Union[Tuple[str, str], List[Tuple[str, str]]], language: str = None) \
+            -> Union[float, List[float]]:
+        """ Semantic textual similarity deals with determining how similar two pieces of texts are.
+
+        Args:
+            text: A pair or pairs of text.
+            language: The language of input text. ``None`` to use the default language.
+
+        Examples::
+
+            HanLP.semantic_textual_similarity([
+                ('看图猜一电影名', '看图猜电影'),
+                ('无线路由器怎么无线上网', '无线上网卡和无线路由器怎么用'),
+                ('北京到上海的动车票', '上海到北京的动车票'),
+            ])
+            # Output: [0.9764469861984253, 0.0, 0.003458738327026367]
+
+        Returns:
+            Similarities.
+
+        """
+        response = self._send_post_json(self._url + '/semantic_textual_similarity',
+                                        {'text': text, 'language': language or self._language})
+        return response
